pub struct CdcCheckpointHandle { /* private fields */ }Expand description
Handle used by downstream code after it has durably accepted an event.
Implementations
Sourceimpl CdcCheckpointHandle
impl CdcCheckpointHandle
Sourcepub fn checkpoint(&self, offset: CdcOffset) -> CdcResult<()>
pub fn checkpoint(&self, offset: CdcOffset) -> CdcResult<()>
Persist and announce a downstream checkpoint.
The replication task will advance PostgreSQL feedback only after all events in the next contiguous transaction have been checkpointed.
pub async fn checkpoint_async(&self, offset: CdcOffset) -> CdcResult<()>